<?xml version="1.0" encoding="UTF-8"?>
<!-- 
	This example code is licensed under a Creative Commons Attribution 3.0 Unported License
	(see http://creativecommons.org/licenses/by/3.0/).
	
	This work is derived on code originally developed by Keith Falghrain et al.
	(see http://code.google.com/p/ickmull/).
	
	Prerequisite:
		any standard xslt 1.0 engine.
	
	Author: peppo.bonelli@gmail.com - November 2012
	Minor modification Dorothy J Hoskins - Nov. 2012
-->


<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	version="1.0">
	
	<xsl:output encoding="UTF-8" indent="yes" method="xml"/>
	
	
	<!-- Fixed strings to indicate ID and ICML version and software version -->
	<!-- These are for my build of IDCS5.5 MacOSX DJH: seems to work OK on PCs -->
	<xsl:variable name="icml-decl-pi">
		<xsl:text>style="50" type="snippet" readerVersion="6.0" featureSet="257" product="7.5(142)"</xsl:text>
	</xsl:variable>
	<xsl:variable name="snippet-type-pi">
		<xsl:text>SnippetType="InCopyInterchange"</xsl:text>
	</xsl:variable>	
	
	<!-- ==================================================================== -->
	<!-- Document styles, presets and document root -->
	<!-- ==================================================================== -->
	<xsl:template match="book"> <!-- put here your source XML doc root tag name DJH when making one text flow from the source file -->
		<xsl:processing-instruction name="aid">
			<xsl:value-of select="$icml-decl-pi"/>
		</xsl:processing-instruction>
		<xsl:processing-instruction name="aid">
			<xsl:value-of select="$snippet-type-pi"/>
		</xsl:processing-instruction>
		<Document DOMVersion="6.0" Self="docbook2Id-helloWorld">
			<RootCharacterStyleGroup Self="character_styles">
				<!-- define here the styles names you want in ID-->
				<!-- to see the full format options export to ICML from your ID template and use whatever option you need. Here we use the bare minimal needed-->
				<!-- you can define here all the typography, however, that is probably better done in the ID template -->
				<CharacterStyle Self="CharacterStyle/$ID/[No character style]" Name="$ID/[No character style]"/>
				<CharacterStyle Self="CharacterStyle/italic" Name="italic"/>
			</RootCharacterStyleGroup>
			<RootParagraphStyleGroup Self="paragraph_styles">
				<ParagraphStyle Self="ParagraphStyle/$ID/[No paragraph style]" Name="$ID/[No paragraph style]"/>
				<ParagraphStyle Self="ParagraphStyle/chapterTitle" Name="chapterTitle"/>
				<!-- modification DJH Nov. 2012 added more styels for different titles -->
				<!-- note that each style needs to be defined in the InDesign tempalte to see different design looks -->
				<ParagraphStyle Self="ParagraphStyle/prefaceTitle" Name="prefaceTitle"/>
				<ParagraphStyle Self="ParagraphStyle/glossaryTitle" Name="glossaryTitle"/>
				<ParagraphStyle Self="ParagraphStyle/sect1Title" Name="sect1Title"/>
				<ParagraphStyle Self="ParagraphStyle/para" Name="para"/>
				<ParagraphStyle Self="ParagraphStyle/glossterm" Name="glossterm"/>
				<ParagraphStyle Self="ParagraphStyle/glossdef" Name="glossdef"/>
			</RootParagraphStyleGroup>
			<Story Self="default_story" AppliedTOCStyle="n" TrackChanges="false" StoryTitle="DefaultStory" AppliedNamedGrid="n">
				<StoryPreference OpticalMarginAlignment="false" OpticalMarginSize="12" FrameType="TextFrameType" StoryOrientation="Horizontal" StoryDirection="LeftToRightDirection"/>
				<InCopyExportOption IncludeGraphicProxies="true" IncludeAllResources="false"/>
				<xsl:apply-templates/>
			</Story>
		</Document>
	</xsl:template>
	
	<!-- ==================================================================== -->
	<!-- Template definitions for transforming from docbook DTD to ICML -->
	<!-- DJH Similar templates can be created for other XML content models -->
	<!-- ==================================================================== -->
	<!-- Call template para-style-range passing style names as defined above
		and source content nodes to build ICML paras-->
	
	<xsl:template match="bookinfo"/><!-- In this example we skip metadata. In a real case we will build a colophon -->

	<xsl:template match="chapter"><!-- no output for chapter wrapper element, just pass through it -->
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="preface">
		<xsl:call-template name="para-style-range">
			<xsl:with-param name="style-name">chapterLabel</xsl:with-param>
			<xsl:with-param name="textStr" select="'Preface'"/>
		</xsl:call-template>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="glossary">
		<xsl:call-template name="para-style-range">
			<xsl:with-param name="style-name">chapterLabel</xsl:with-param>
			<xsl:with-param name="textStr" select="'Glossary'"/>
		</xsl:call-template>
		<xsl:apply-templates/>
	</xsl:template>
	<!-- make titles use different styles according to their parent DJH Nov. 2012 -->
	<xsl:template match="title[parent::chapter] | title[parent::glossary] | title[parent::preface] | title[parent::sect1]">
		<xsl:variable name="myParent"><xsl:value-of select="name(..)"/><xsl:text>Title</xsl:text></xsl:variable>
		<xsl:call-template name="para-style-range">
			<xsl:with-param name="style-name"><xsl:value-of select="$myParent"/></xsl:with-param>
			<xsl:with-param name="ContentNodes" select="node()"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="sect1"><!-- pass through this wrapper element -->
		<xsl:apply-templates/>
	</xsl:template>
	
	
	<xsl:template match="glossentry"><!-- pass through this wrapper element -->
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="glossterm">
		<xsl:call-template name="para-style-range">
			<xsl:with-param name="style-name">glossterm</xsl:with-param>
			<xsl:with-param name="ContentNodes" select="node()"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="glossdef">
		<xsl:call-template name="para-style-range">
			<xsl:with-param name="style-name">glossdef</xsl:with-param>
			<xsl:with-param name="ContentNodes" select="para"/>
		</xsl:call-template>
	</xsl:template>

	<!-- this is the default para. Specialize it as needed using source xml semantics/structure or explicit styles in attributes and or roles-->
	<xsl:template match="para">
		<xsl:call-template name="para-style-range">
			<xsl:with-param name="style-name">para</xsl:with-param>
			<xsl:with-param name="ContentNodes" select="node()"/>
		</xsl:call-template>
	</xsl:template>

	<!-- ==================================================================== -->
	<!-- Inlines -->
	<!-- ==================================================================== -->

	<xsl:template match="emphasis[contains(@role, 'italic')]" mode="character-style-range">
		<xsl:call-template name="char-style-range">
			<xsl:with-param name="style-name">italic</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="text()" mode="character-style-range">
		<xsl:call-template name="char-style-range"/>
	</xsl:template>
	
	<!-- ==================================================================== -->
	<!-- Named templates called to build ID para and char ranges (Probably no changes needed below -->
	<!-- ==================================================================== -->
	
	<xsl:template name="para-style-range">
		<!-- The name of the paragraph style in InDesign -->
		<xsl:param name="style-name">$ID/[No paragraph style]</xsl:param>
		<xsl:param name="ContentNodes"/>
		<xsl:param name="textStr" select="''"/><!-- use this for inserting fixed strings (e.g. chapter labels) -->
		<ParagraphStyleRange>
			<xsl:attribute name="AppliedParagraphStyle">
				<xsl:value-of select="concat('ParagraphStyle/', $style-name)"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="$ContentNodes">
					<xsl:apply-templates select="$ContentNodes" mode="character-style-range"/>
				</xsl:when>
				<xsl:when test="$textStr != ''">
					<CharacterStyleRange>
						<xsl:attribute name="AppliedCharacterStyle">$ID/[No character style]</xsl:attribute>
						<Content><xsl:value-of select="$textStr"/></Content>
					</CharacterStyleRange>
				</xsl:when>
			</xsl:choose>
			<Br/>
		</ParagraphStyleRange>
	</xsl:template>


	<xsl:template name="char-style-range">
		<!-- The name of the character style in InDesign -->
		<xsl:param name="style-name">$ID/[No character style]</xsl:param>
		<CharacterStyleRange>
			<xsl:attribute name="AppliedCharacterStyle">
				<xsl:value-of select="concat('CharacterStyle/', $style-name)"/>
			</xsl:attribute>
			<Content><xsl:value-of select="."/></Content>
		</CharacterStyleRange>
	</xsl:template>
	
</xsl:stylesheet>